slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPAppendOptionsPrefix

Appends to the prefix used for searching for all NEP options in the database.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPAppendOptionsPrefix(NEP nep,const char *prefix)

Logically Collective on nep

### Input Parameters

| nep | - the nonlinear eigensolver context
| prefix | - the prefix string to prepend to all NEP option requests

### Notes

A hyphen (-) must NOT be given at the beginning of the prefix name. The first character of all runtime options is AUTOMATICALLY the hyphen.

### See Also

NEPSetOptionsPrefix(), NEPGetOptionsPrefix()

### Level

advanced

### Location

src/nep/interface/nepopts.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages